@@ -1,7 +1,9 @@
 """Generic Utility helper functions."""
+from __future__ import annotations
+
 import base64
 import json
-from typing import Any, Dict, Union
+from typing import Any
 
 from ..exceptions import UnparseableValue
 
@@ -17,7 +19,12 @@ def convert_bytes_to_base64(data: bytes) -> str:
     return base64.b64encode(data).decode("ascii")
 
 
-def parse_buffer(value: Union[Dict[str, Any], str]) -> str:
+def convert_base64_to_bytes(data: str) -> bytes:
+    """Convert base64 data to bytes for deserialization."""
+    return base64.b64decode(data)
+
+
+def parse_buffer(value: dict[str, Any] | str) -> str:
     """Parse value from a buffer data type."""
     if isinstance(value, dict):
         return parse_buffer_from_dict(value)
@@ -28,7 +35,7 @@ def parse_buffer(value: Union[Dict[str, Any], str]) -> str:
     return value
 
 
-def parse_buffer_from_dict(value: Dict[str, Any]) -> str:
+def parse_buffer_from_dict(value: dict[str, Any]) -> str:
     """Parse value dictionary from a buffer data type."""
     if value.get("type") != "Buffer" or "data" not in value:
         raise UnparseableValue(f"Unparseable value: {value}") from ValueError(
